@@ -32,6 +32,12 @@ from jinja2 import Environment, StrictUndefined, \
     BaseLoader, TemplateNotFound, PrefixLoader
 from contextlib import contextmanager
 
+DEFAULT_CONTEXT = {x.__name__: x for x in (
+  abs, all, any, bin, bool, callable, chr, complex, dict, divmod,
+  enumerate, filter, float, format, frozenset, hex, int,
+  isinstance, iter, len, list, map, max, min, next, oct, ord,
+  pow, repr, reversed, round, set, sorted, str, sum, tuple, zip)}
+
 _buildout_safe_dumps = getattr(zc.buildout.buildout, 'dumps', None)
 DUMPS_KEY = 'dumps'
 DEFAULT_IMPORT_DELIMITER = '/'
@@ -166,7 +172,7 @@ class Recipe(object):
         self.rendered = options['rendered']
         self.extension_list = [x for x in (y.strip()
             for y in options.get('extensions', '').split()) if x]
-        self.context = context = {}
+        self.context = context = DEFAULT_CONTEXT.copy()
         if _buildout_safe_dumps is not None:
             context[DUMPS_KEY] = _buildout_safe_dumps
         for line in options.get('context', '').splitlines(False):
