@@ -38,7 +38,7 @@ def test_suite():
       filename,
       setUp=setUp,
       tearDown=testing.buildoutTearDown,
-      optionflags=doctest.ELLIPSIS,
+      optionflags=(doctest.ELLIPSIS | doctest.NORMALIZE_WHITESPACE),
     ) for filename in [
       'README.txt',
       'README.jinja2.txt',
